@@ -14,7 +14,7 @@ from .thermo_model import (ThermoModel,
                            create_axis_labels)
 from ..exceptions import DomainError
 from .units_of_measure import definitions
-from .functor import functor_lookalike
+from .functor import Functor, functor_lookalike
 
 __all__ = ('ThermoModelHandle',
            'TDependentModelHandle',
@@ -76,56 +76,75 @@ def as_model(models, key):
 
 @functor_lookalike
 class ThermoModelHandle:
-    __slots__ = ('chemical', 'var', 'models',)
+    __slots__ = ('_chemical', '_var', '_models',)
+    
+    @property
+    def chemical(self):
+        """[Chemical] Parent chemical."""
+        return self._chemical
+    @property
+    def var(self):
+        """[str] Return variable."""
+        return self._var
+    @property
+    def models(self):
+        """Deque[ThermoModel] All models."""
+        return self._models
+    
+    def load_data_from(self, data:dict):
+        for model in self._models: model.load_data_from(data)
+    
+    def set_value(self, var, value):
+        for model in self._models: model.set_value(var, value)
     
     def plot_vs_T(self, T_range=None, T_units=None, units=None, 
                   P=101325, label_axis=True, **plot_kwargs):
         Ts, Ys = self.tabulate_vs_T(T_range, T_units, units, P)
         plt.plot(Ts, Ys, **plot_kwargs)
-        if label_axis: create_axis_labels('T', T_units, self.var, units)
+        if label_axis: create_axis_labels('T', T_units, self._var, units)
         plt.legend()
         
     def plot_vs_P(self, P_range=None, P_units=None, units=None,
                   T=298.15, label_axis=True, **plot_kwargs):
         Ps, Ys = self.tabulate_vs_P(P_range, P_units, units, T)
         plt.plot(Ps, Ys, **plot_kwargs)
-        if label_axis: create_axis_labels('P', P_units, self.var, units)
+        if label_axis: create_axis_labels('P', P_units, self._var, units)
         plt.legend()
     
     def plot_models_vs_T(self, T_range=None, T_units=None, units=None,
                          P=101325, label_axis=True, **plot_kwargs):
         for model in self: model.plot_vs_T(T_range, T_units, units, P, False, **plot_kwargs)
-        if label_axis: create_axis_labels('T', T_units, self.var, units)
+        if label_axis: create_axis_labels('T', T_units, self._var, units)
         plt.legend()
     
     def plot_models_vs_P(self, P_range=None, P_units=None, units=None,
                          T=298.15, label_axis=True, **plot_kwargs):
         for model in self: model.plot_vs_P(P_range, P_units, units, T, False, **plot_kwargs)
-        if label_axis: create_axis_labels('P', P_units, self.var, units)
+        if label_axis: create_axis_labels('P', P_units, self._var, units)
         plt.legend()
     
     def __init__(self, var, models=None):
-        self.chemical = None
-        self.var = var
-        self.models = deque(models) if models else deque()
+        self._chemical = None
+        self._var = var
+        self._models = deque(models) if models else deque()
     
     def __getitem__(self, index):
-        return self.models[index]
+        return self._models[index]
     
     def __setitem__(self, index, model):
         assert isinstance(model, ThermoModel), (
             "a 'ThermoModelHandle' object may only "
             "contain 'ThermoModel' objects")
-        self.models[index] = model
+        self._models[index] = model
 	
     def __iter__(self):
-        return iter(self.models)
+        return iter(self._models)
     
     def __bool__(self):
-        return bool(self.models)
+        return bool(self._models)
     
     def copy(self):
-        return self.__class__(self.var, self.models.copy())
+        return self.__class__(self._var, self._models.copy())
     __copy__ = copy
     
     def set_model_priority(self, key, priority=0):
@@ -140,7 +159,7 @@ class ThermoModelHandle:
             Index to place model. The default is 0.
 
         """
-        models = self.models
+        models = self._models
         model = as_model(models, key)
         models.remove(model)
         models.insert(priority, model)
@@ -157,8 +176,8 @@ class ThermoModelHandle:
             Index to place model. The default is 0.
             
         """
-        index = as_model_index(self.models, key)
-        self.models.rotate(priority - index)
+        index = as_model_index(self._models, key)
+        self._models.rotate(priority - index)
     
     def add_model(self, evaluate=None,
                   Tmin=None, Tmax=None,
@@ -203,11 +222,11 @@ class ThermoModelHandle:
             model = evaluate
         else:
             model = thermo_model(evaluate, Tmin, Tmax, Pmin,
-                                 Pmax, name, self.var, **funcs)
+                                 Pmax, name, self._var, **funcs)
         if top_priority:
-            self.models.appendleft(model)
+            self._models.appendleft(model)
         else:
-            self.models.append(model)    
+            self._models.append(model)    
         return evaluate
        
     def remove(self, key):
@@ -220,14 +239,14 @@ class ThermoModelHandle:
             Index, name, or the model itself.
             
         """
-        model = as_model(self.models, key)
-        self.models.remove(model)
+        model = as_model(self._models, key)
+        self._models.remove(model)
        
     def show(self):
         info = f"{self}\n"
-        if self.models:
+        if self._models:
             models = "\n".join([f'[{i}] {model.name}'
-                                for i, model in enumerate(self.models)])
+                                for i, model in enumerate(self._models)])
         else:
             models = "(no models available)"
         print(info + models)
@@ -244,26 +263,27 @@ class TDependentModelHandle(ThermoModelHandle):
         
     @property
     def Tmin(self):
-        return min([i.Tmin for i in self.models])
+        return min([i.Tmin for i in self._models])
     @property
     def Tmax(self):
-        return max([i.Tmax for i in self.models])
+        return max([i.Tmax for i in self._models])
     
     def __call__(self, T, P=None):
-        for model in self.models:
+        for model in self._models:
             if model.indomain(T): return model.evaluate(T)
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise ValueError(f"{no_valid_model(self._chemical, self._var)} "
                          f"at T={T:.2f} K")
+    
     at_T = __call__
     
     def try_out(self, T, P=None):
-        for model in self.models:
+        for model in self._models:
             if model.indomain(T): return model.evaluate(T)
     
     def differentiate_by_T(self, T, P=None, dT=1e-12):
-        for model in self.models:
+        for model in self._models:
             if model.indomain(T): return model.differentiate_by_T(T, dT=dT)
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise ValueError(f"{no_valid_model(self._chemical, self._var)} "
                          f"at T={T:.2f} K")
         
     def differentiate_by_P(self, T, P=None, dP=1e-12):
@@ -272,7 +292,7 @@ class TDependentModelHandle(ThermoModelHandle):
     def integrate_by_T(self, Ta, Tb, P=None):
         integral = 0.
         defined = hasattr
-        for model in self.models:
+        for model in self._models:
             if not defined(model, 'integrate_by_T'): continue
             Tmax = model.Tmax
             Tmin = model.Tmin
@@ -287,7 +307,7 @@ class TDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T(Tmin, Tb)
                 Tb = Tmin
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise ValueError(f"{no_valid_model(self._chemical, self._var)} "
                          f"between T={Ta:.2f} to {Tb:.2f} K")
     
     def integrate_by_P(self, Pa, Pb, T):
@@ -296,7 +316,7 @@ class TDependentModelHandle(ThermoModelHandle):
     def integrate_by_T_over_T(self, Ta, Tb, P=None):
         integral = 0.
         defined = hasattr
-        for model in self.models:
+        for model in self._models:
             if not defined(model, 'integrate_by_T_over_T'): continue
             Tmax = model.Tmax
             Tmin = model.Tmin
@@ -311,7 +331,7 @@ class TDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T_over_T(Tmin, Tb)
                 Tb = Tmin
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise ValueError(f"{no_valid_model(self._chemical, self._var)} "
                          f"between T={Ta:.2f} to {Tb:.2f} K")
     
     
@@ -326,44 +346,45 @@ class TPDependentModelHandle(ThermoModelHandle):
     
     @property
     def Pmin(self):
-        return min([i.Pmin for i in self.models])
+        return min([i.Pmin for i in self._models])
     @property
     def Pmax(self):
-        return max([i.Pmax for i in self.models])
+        return max([i.Pmax for i in self._models])
     
     def __call__(self, T, P):
-        for model in self.models:
+        for model in self._models:
             if model.indomain(T, P): return model.evaluate(T, P)
-        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
+
     def at_T(self, T):
         isa = isinstance
-        for model in self.models:
+        for model in self._models:
             if isa(model, TDependentModel) and model.indomain(T):
                 return model.evaluate(T)
-        raise ValueError(f"{no_valid_model(self.chemical, self.var)} "
+        raise ValueError(f"{no_valid_model(self._chemical, self._var)} "
                          f"at T={T:.2f} K")
 
     def try_out(self, T, P):
-        for model in self.models:
+        for model in self._models:
             if model.indomain(T, P): return model.evaluate(T, P)
 
     def differentiate_by_T(self, T, P):
-        for model in self.models:
+        for model in self._models:
             if model.indomain(T, P): return model.differentiate_by_T(T, P)
-        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
             
     def differentiate_by_P(self, T, P):
-        for model in self.models:
+        for model in self._models:
              if model.indomain(T, P): return model.differentiate_by_P(T, P)
-        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                          f"at T={T:.2f} K and P={P:.0f} Pa")
 
     def integrate_by_T(self, Ta, Tb, P):
         integral = 0
         defined = hasattr
-        for model in self.models:
+        for model in self._models:
             if not (defined(model, 'integrate_by_T') and model.Pmin < P < model.Pmax): continue
             Tmax = model.Tmax
             Tmin = model.Tmin    
@@ -378,13 +399,13 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T(Tmin, Tb, P)
                 Tb = Tmin
-        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                          f"between T={Ta:.2f} to {Tb:.2f} K at P={P:.0f} Pa")
     
     def integrate_by_P(self, Pa, Pb, T):
         integral = 0
         defined = hasattr
-        for model in self.models:
+        for model in self._models:
             if not (defined(model, 'integrate_by_P')
                     and model.Tmin < T < model.Tmax): continue
             Pmin = model.Pmin
@@ -400,13 +421,13 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Pmin < Pb:
                 integral += model.integrate_by_P(Pmin, Pb, T)
                 Pb = Pmin
-        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                          f"between P={Pa:5g} to {Pb:5g} Pa ast T={T:.2f}")
     
     def integrate_by_T_over_T(self, Ta, Tb, P):
         integral = 0
         defined = hasattr
-        for model in self.models:
+        for model in self._models:
             if not (defined(model, 'integrate_by_T_over_T')
                     and model.Pmin < P < model.Pmax): continue
             Tmax = model.Tmax
@@ -422,7 +443,7 @@ class TPDependentModelHandle(ThermoModelHandle):
             elif ub_satisfied and Tmin < Tb:
                 integral += model.integrate_by_T_over_T(Tmin, Tb, P)
                 Tb = Tmin
-        raise DomainError(f"{no_valid_model(self.chemical, self.var)} "
+        raise DomainError(f"{no_valid_model(self._chemical, self._var)} "
                          f"between T={Ta:.2f} to {Tb:.2f} K")
         
             
