@@ -4,13 +4,14 @@ Created on Wed Mar 20 18:40:05 2019
 
 @author: yoelr
 """
-from ..utils import thermo_user, njitable
+from flexsolve import njitable
+from ..utils import thermo_user, Cache
 from scipy.optimize import differential_evolution
 from .._thermal_condition import ThermalCondition
 from .vle import VLE
 import numpy as np
 
-__all__ = ('LLE',)
+__all__ = ('LLE', 'LLECache')
 
 def liquid_activities(mol_l, T, f_gamma):
     total_mol_l = mol_l.sum()
@@ -128,3 +129,6 @@ class LLE:
     thermal_condition = VLE.thermal_condition
     __format__ = VLE.__format__
     __repr__ = VLE.__repr__
+
+class LLECache(Cache): load = LLE
+del Cache    
\ No newline at end of file
