@@ -7,11 +7,9 @@ Created on Wed Oct 30 12:07:13 2019
 from . import (acentric,
                combustion,
                electrolyte_conductivity,
-               coolprop,
                critical,
                dipole,
                dippr,
-               datasheet,
                electrolytes,
                elements,
                environment,
@@ -19,14 +17,12 @@ from . import (acentric,
                heat_capacity,
                identifiers,
                joback,
-               law,
                lennard_jones,
                miscdata,
                permittivity,
                phase_change,
                reaction,
                refractivity,
-               safety,
                solubility,
                interface,
                thermal_conductivity,
@@ -40,12 +36,12 @@ from . import (acentric,
 __all__ = ('combustion', 'electrolyte_conductivity', 'critical', 'dipole',
            'electrolytes', 'elements', 'environment',
            'eos', 'heat_capacity',  'identifiers', 
-           'joback', 'law', 'lennard_jones', 'miscdata',
+           'joback', 'lennard_jones', 'miscdata',
            'permittivity', 'phase_change',  'reaction', 
-           'refractivity', 'safety', 'solubility',
+           'refractivity', 'solubility',
            'interface', 'thermal_conductivity', 'triple', 
            'utils', 'vapor_pressure', 'virial',
 		   'viscosity', 'volume', 'acentric', 
-           'coolprop', 'datasheet', 'dippr',)
+           'datasheet', 'dippr',)
 
 
