@@ -33,7 +33,7 @@ Hf_combustion_products = {
 
 def get_combustion_stoichiometry(atoms: dict, 
                                  MW: float=None) -> dict:
-    """
+    r"""
     Return a dictionary of the combustion stoichiometry of a chemical.
     
     Parameters
@@ -216,8 +216,13 @@ class CombustionData:
         '''
         if CAS in combustion_products:
             return cls("", 0, 0, Hf)
+        if not atoms:
+            raise RuntimeError('no atomic formula to estimate combustion stoichiometry')
         stoichiometry = get_combustion_stoichiometry(atoms, MW)
         if method == 'Stoichiometry':
+            if Hf is None:
+                raise RuntimeError('no heat of formation to estimate '
+                                   'heat of combustion from stoichiometry')
             HHV = estimate_HHV_from_stoichiometry(stoichiometry, Hf)
             N_H2O = stoichiometry.get('H2O', 0)
         elif method == 'Dulong':
