@@ -65,7 +65,7 @@ from ..base import (InterpolatedTDependentModel,
                     ThermoModelHandle,
                     TDependentModel,
                     TPDependentHandleBuilder, 
-                    PhaseTPPropertyBuilder, 
+                    PhaseTPHandleBuilder, 
                     kappa)
 from .._constants import R, N_A, k
 from math import log, exp
@@ -329,7 +329,7 @@ def DIPPR9G(T, P, Tc, Pc, k_l):
     r'''
     Notes
     -----
-    Adjustes for pressure the thermal conductivity of a liquid using an
+    Adjusts for pressure. the thermal conductivity of a liquid using an
     emperical formula based on [10]_, but as given in [11]_.
     
     .. math::
@@ -369,7 +369,7 @@ def Missenard(T, P, Tc, Pc, k_l):
     r'''
     Notes
     -----
-    Adjustes for pressure the thermal conductivity of a liquid using an
+    Adjusts for pressure. the thermal conductivity of a liquid using an
     emperical formula based on [10]_, but as given in [12]_.
     
     .. math::
@@ -397,6 +397,10 @@ def Missenard(T, P, Tc, Pc, k_l):
 @TPDependentHandleBuilder('kappa.l')
 def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega, Hfus):
     add_model = handle.add_model
+    if all((Tc, Pc)):
+        data = (Tc, Pc, handle)
+        add_model(DIPPR9G.from_args(data))
+        add_model(Missenard.from_args(data))
     if CAS in _Perrys2_315:
         _, C1, C2, C3, C4, C5, Tmin, Tmax = _Perrys2_315[CAS]
         data = (C1, C2, C3, C4, C5)
@@ -409,24 +413,19 @@ def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega, H
         Tmin = Ts[0]
         Tmax = Ts[-1]
         add_model(InterpolatedTDependentModel(Ts, Ys, Tmin=Tmin, Tmax=Tmax))
-    data = (MW, Tm)
-    if all(data):
-        # Works down to 0, has a nice limit at T = Tm+793.65 from Sympy
-        add_model(Sheffy_Johnson.from_args(data), 0, 793.65)
-    data = (MW, Tb, Tc)
-    if all(data):
-        add_model(Sato_Riedel.from_args(data))
     data = (MW, Tb, Pc, omega)
     if all(data):
         add_model(Gharagheizi_liquid.from_args(data), Tb, Tc)
     data = (MW, Tc, Pc, omega)
     if all(data):
         add_model(Nicola.from_args(data))
-    data = (MW, Tc, omega, Hfus)
-    if all((Tc, Pc)):
-        data = (Tc, Pc, handle.models)
-        add_model(DIPPR9G.from_args(data))
-        add_model(Missenard.from_args(data))
+    data = (MW, Tb, Tc)
+    if all(data):
+        add_model(Sato_Riedel.from_args(data))
+    data = (MW, Tm)
+    if all(data):
+        # Works down to 0, has a nice limit at T = Tm+793.65 from Sympy
+        add_model(Sheffy_Johnson.from_args(data), 0, 793.65)
     data = (MW,)
     if MW:
         add_model(Lakshmi_Prasad.from_args(data))
@@ -461,7 +460,7 @@ def Eucken(T, MW, Cn, mu_g):
     
     '''
     if callable(Cn): Cn = Cn(T)
-    if callable(mu_g): mu_g = mu_g(T)
+    if callable(mu_g): mu_g = mu_g.at_T(T)
     Cv = Cn - R
     MW = MW/1000.
     return (1. + 9/4./(Cv/R))*mu_g*Cv/MW
@@ -491,7 +490,7 @@ def Eucken_modified(T, MW, Cn, mu):
     
     '''
     if callable(Cn): Cn = Cn(T)
-    if callable(mu): mu = mu(T)
+    if callable(mu): mu = mu.at_T(T)
     Cv = Cn - R
     MW = MW/1000.
     return (1.32 + 1.77/(Cv/R))*mu*Cv/MW
@@ -499,7 +498,7 @@ def Eucken_modified(T, MW, Cn, mu):
 @kappa.g
 def DIPPR9B_linear(T, MW, Cn, mu, Tc):
     if callable(Cn): Cn = Cn(T)
-    if callable(mu): mu = mu(T)
+    if callable(mu): mu = mu.at_T(T)
     Cv = 1000 * (Cn - R) # J/mol/K to J/kmol/K
     Tr = T/Tc
     return mu/MW*(1.30*Cv + 14644 - 2928.80/Tr)
@@ -507,14 +506,14 @@ def DIPPR9B_linear(T, MW, Cn, mu, Tc):
 @kappa.g    
 def DIPPR9B_monoatomic(T, MW, Cn, mu):
     if callable(Cn): Cn = Cn(T)
-    if callable(mu): mu = mu(T)
+    if callable(mu): mu = mu.at_T(T)
     Cv = 1000 * (Cn - R) # J/mol/K to J/kmol/K
     return 2.5*mu*Cv/MW
 
 @kappa.g
 def DIPPR9B_nonlinear(T, MW, Cn, mu):
     if callable(Cn): Cn = Cn(T)
-    if callable(mu): mu = mu(T)
+    if callable(mu): mu = mu.at_T(T)
     Cv = 1000 * (Cn - R) # J/mol/K to J/kmol/K
     return mu/MW*(1.15*Cv + 16903.36)
 
@@ -550,7 +549,7 @@ def Chung(T, MW, Tc, omega, Cn, mu):
     
     '''
     if callable(Cn): Cn = Cn(T)
-    if callable(mu): mu = mu(T)
+    if callable(mu): mu = mu.at_T(T)
     Cv = Cn - R 
     MW = MW/1000. # g/mol to kg/mol
     alpha = Cv/R - 1.5
@@ -632,7 +631,6 @@ def Gharagheizi_gas(T, MW, Tb, Pc, omega):
     r'''
     Notes
     -----
-    
     Estimates the thermal conductivity of a gas as a function of
     temperature using the CSP method of Gharagheizi [6]_. A  convoluted
     method claiming high-accuracy and using only statistically significant
@@ -961,44 +959,44 @@ def Chung_dense(T, P, MW, Tc, Vc, omega, Cn, V_g, mu_g, dipole, association=0):
 
 @TPDependentHandleBuilder('kappa.g')
 def thermal_conductivity_gas_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, dipole, Vg, Cn, mug):
-    data = (MW, Tb, Pc, omega)
     add_model = handle.add_model
-    if all(data):
-        add_model(Gharagheizi_gas.from_args(data))
-    data = (MW, Cn, mug, Tc)
     if CAS in VDI_saturation_dict:
         Ts, Ys = VDI_tabular_data(CAS, 'K (g)')
         add_model(InterpolatedTDependentModel(Ts, Ys))
-    if CAS in _VDI_PPDS_10:
-        _,  *data = _VDI_PPDS_10[CAS].tolist()
-        data.reverse()
-        add_model(horner_polynomial.from_kwargs({'coeffs': data}))
+    # if CAS in _VDI_PPDS_10:
+    #     _,  *data = _VDI_PPDS_10[CAS].tolist()
+    #     data.reverse()
+    #     add_model(horner_polynomial.from_kwargs({'coeffs': data}))
+    data = (MW, Cn, mug, Tc)
     if all(data):
         add_model(DIPPR9B_linear.from_args(data))
+    data = (MW, Tb, Pc, omega)
+    if all(data):
+        add_model(Gharagheizi_gas.from_args(data))   
     data = (MW, Tc, omega, Cn, mug)
     if all(data):
         add_model(Chung.from_args(data))
     data = (MW, Tc, Vc, Zc, omega, Cn)
     if all(data):
         add_model(Eli_Hanley.from_args(data))
-    data = (MW, Cn, mug)
-    if all(data):
-        add_model(Eucken_modified.from_args(data))
-        add_model(Eucken.from_args(data))
     data = (MW, Tc, Vc, Zc, omega, Cn, Vg)
-    if all((MW, Tc, Vc, Zc, omega, Cn, Vg)):
+    if all(data):
         add_model(Eli_Hanley_dense.from_args(data))
     data = (MW, Tc, Vc, omega, Cn, Vg, mug, dipole)
     if all(data):
         add_model(Chung_dense.from_args(data))
-    data = (MW, Tc, Pc, Vc, Zc, Vg, handle.models)
+    data = (MW, Tc, Pc, Vc, Zc, Vg, handle)
     if all(data):
         add_model(Stiel_Thodos_dense.from_args(data))
+    data = (MW, Cn, mug)
+    if all(data):
+        add_model(Eucken_modified.from_args(data))
+        add_model(Eucken.from_args(data))
     # TODO: Fix propblem with values
     # if CAS in _Perrys2_314:
     #     _, *data, Tmin, Tmax = _Perrys2_314[CAS]
     #     add_model(DIPPR9B_linear(data), Tmin, Tmax)
 
-thermal_conductivity_handle = PhaseTPPropertyBuilder('kappa', None,
+thermal_conductivity_handle = PhaseTPHandleBuilder('kappa', None,
                                                      thermal_conductivity_liquid_handle,
                                                      thermal_conductivity_gas_handle)
